## Some useful things from the world of functional programming for python
The goal is not to cover "everything" about functional programming, but to provide some useful things in the most practical way (at least from the author's perspective).  

- The library is minimalistic and has no dependencies.  
- Provides advanced, feature-rich currying decorators. 
- Resilient effects.  
- Emphasizes strict adherence to contracts and a clear separation between synchronous and asynchronous operations.


Full documentation is available at the link: https://github.com/msuhov1988/Mafunca